@@ -48,6 +48,7 @@
 #include <kcategorizedsortfilterproxymodel.h>
 #include <kaboutdata.h>
 #include <kaboutapplicationdialog.h>
+#include <KStandardGuiItem>
 
 #define MARGIN 5
 
@@ -280,9 +281,9 @@ KPluginSelector::KPluginSelector(QWidget *parent)
     d->listView->setMouseTracking(true);
     d->listView->viewport()->setAttribute(Qt::WA_Hover);
 
-    connect(d->lineEdit, SIGNAL(textChanged(QString)), d->proxyModel, SLOT(invalidate()));
-    connect(pluginDelegate, SIGNAL(changed(bool)), this, SIGNAL(changed(bool)));
-    connect(pluginDelegate, SIGNAL(configCommitted(QByteArray)), this, SIGNAL(configCommitted(QByteArray)));
+    connect(d->lineEdit, &QLineEdit::textChanged, d->proxyModel, &QSortFilterProxyModel::invalidate);
+    connect(pluginDelegate, &Private::PluginDelegate::changed, this, &KPluginSelector::changed);
+    connect(pluginDelegate, &Private::PluginDelegate::configCommitted, this, &KPluginSelector::configCommitted);
 
     layout->addWidget(d->lineEdit);
     layout->addWidget(d->listView);
@@ -316,10 +317,10 @@ void KPluginSelector::addPlugins(const QString &componentName,
         return;
     }
 
-    Q_ASSERT(config);
     if (!config) {
         config = KSharedConfig::openConfig(componentName + QStringLiteral("rc"));
     }
+    Q_ASSERT(config);
 
     KConfigGroup cfgGroup(config, "KParts Plugins");
     // qDebug() << "cfgGroup = " << &cfgGroup;
@@ -405,6 +406,16 @@ void KPluginSelector::updatePluginsState()
     }
 }
 
+void KPluginSelector::setConfigurationArguments(const QStringList& arguments)
+{
+    d->kcmArguments = arguments;
+}
+
+QStringList KPluginSelector::configurationArguments() const
+{
+    return d->kcmArguments;
+}
+
 KPluginSelector::Private::PluginModel::PluginModel(KPluginSelector::Private *pluginSelector_d, QObject *parent)
     : QAbstractListModel(parent)
     , pluginSelector_d(pluginSelector_d)
@@ -438,8 +449,7 @@ void KPluginSelector::Private::PluginModel::addPlugins(const QList<KPluginInfo>
         pluginEntry.isCheckable = !pluginInfo.isValid() || !pluginEntry.cfgGroup.isEntryImmutable(pluginInfo.pluginName() + QLatin1String("Enabled"));
 
         if (!pluginEntryList.contains(pluginEntry) && !listToAdd.contains(pluginEntry) &&
-                (!pluginInfo.property(QStringLiteral("X-KDE-PluginInfo-Category")).isValid() ||
-                 !pluginInfo.property(QStringLiteral("X-KDE-PluginInfo-Category")).toString().compare(categoryKey, Qt::CaseInsensitive)) &&
+                (pluginInfo.category().isEmpty() || !pluginInfo.category().compare(categoryKey, Qt::CaseInsensitive)) &&
                 (!pluginInfo.service() || !pluginInfo.service()->noDisplay())) {
             listToAdd << pluginEntry;
 
@@ -676,16 +686,16 @@ QList<QWidget *> KPluginSelector::Private::PluginDelegate::createItemWidgets(con
     QList<QWidget *> widgetList;
 
     QCheckBox *enabledCheckBox = new QCheckBox;
-    connect(enabledCheckBox, SIGNAL(clicked(bool)), this, SLOT(slotStateChanged(bool)));
-    connect(enabledCheckBox, SIGNAL(clicked(bool)), this, SLOT(emitChanged()));
+    connect(enabledCheckBox, &QAbstractButton::clicked, this, &PluginDelegate::slotStateChanged);
+    connect(enabledCheckBox, &QAbstractButton::clicked, this, &PluginDelegate::emitChanged);
 
     QPushButton *aboutPushButton = new QPushButton;
     aboutPushButton->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
-    connect(aboutPushButton, SIGNAL(clicked(bool)), this, SLOT(slotAboutClicked()));
+    connect(aboutPushButton, &QAbstractButton::clicked, this, &PluginDelegate::slotAboutClicked);
 
     QPushButton *configurePushButton = new QPushButton;
     configurePushButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
-    connect(configurePushButton, SIGNAL(clicked(bool)), this, SLOT(slotConfigureClicked()));
+    connect(configurePushButton, &QAbstractButton::clicked, this, &PluginDelegate::slotConfigureClicked);
 
     setBlockedEventTypes(enabledCheckBox, QList<QEvent::Type>() << QEvent::MouseButtonPress
                          << QEvent::MouseButtonRelease << QEvent::MouseButtonDblClick
@@ -808,7 +818,7 @@ void KPluginSelector::Private::PluginDelegate::slotConfigureClicked()
     foreach (const KService::Ptr &servicePtr, pluginInfo.kcmServices()) {
         if (!servicePtr->noDisplay()) {
             KCModuleInfo moduleInfo(servicePtr);
-            KCModuleProxy *currentModuleProxy = new KCModuleProxy(moduleInfo, moduleProxyParentWidget);
+            KCModuleProxy *currentModuleProxy = new KCModuleProxy(moduleInfo, moduleProxyParentWidget, pluginSelector_d->kcmArguments);
             if (currentModuleProxy->realModule()) {
                 moduleProxyList << currentModuleProxy;
                 if (mainWidget && !newTabWidget) {
@@ -849,10 +859,13 @@ void KPluginSelector::Private::PluginDelegate::slotConfigureClicked()
         layout->insertSpacing(-1, marginHint);
 
         QDialogButtonBox *buttonBox = new QDialogButtonBox(&configDialog);
-        buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Cancel);
-        connect(buttonBox, SIGNAL(accepted()), &configDialog, SLOT(accept()));
-        connect(buttonBox, SIGNAL(rejected()), &configDialog, SLOT(reject()));
-        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), SIGNAL(clicked()), this, SLOT(slotDefaultClicked()));
+        buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults);
+        KGuiItem::assign(buttonBox->button(QDialogButtonBox::Ok), KStandardGuiItem::ok());
+        KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::cancel());
+        KGuiItem::assign(buttonBox->button(QDialogButtonBox::RestoreDefaults), KStandardGuiItem::defaults());
+        connect(buttonBox, &QDialogButtonBox::accepted, &configDialog, &QDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, &configDialog, &QDialog::reject);
+        connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QAbstractButton::clicked, this, &PluginDelegate::slotDefaultClicked);
         layout->addWidget(buttonBox);
 
         configDialog.setLayout(layout);
